#!/bin/bash

### RMQ-КС
###
### Copyright (c) 2023, ООО Кейсистемс
###
### Версия 3.12.4

# Определяем каталог выполнения текущего скрипта
dks_bashfile_dir="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"

# Параметры: порт (обязательный)

rmq_port=$1
user=$2
pwd=$3
erl_epmd_port=$4
contsoft=$5

# порт для веб морды
http_rmq_port="1${rmq_port}"

rmq_msg_title="Брокер сообщений"
epmd_msg_title="Сервис epmd"

#============== Основные переменные константы =====================
tag_ver=$($dks_bashfile_dir/dks_const_var.sh tag_ver)
tag_name=$($dks_bashfile_dir/dks_const_var.sh tag_name)


# Контейнер
dks_inst_name=$($dks_bashfile_dir/dks_const_var.sh dks_inst_name)
dks_inst_path=$($dks_bashfile_dir/dks_const_var.sh dks_inst_path)

dks_cont_name=$($dks_bashfile_dir/dks_const_var.sh      dks_cont_name      ${rmq_port})
dks_serv_name=$($dks_bashfile_dir/dks_const_var.sh      dks_serv_name      ${rmq_port})
dks_image_tar_file=$($dks_bashfile_dir/dks_const_var.sh dks_image_tar_file ${rmq_port})

# RMQ
rmq_inst_name=$($dks_bashfile_dir/dks_const_var.sh rmq_inst_name ${rmq_port})
rmq_etc_path=$($dks_bashfile_dir/dks_const_var.sh  rmq_etc_path  ${rmq_port})
rmq_data_path=$($dks_bashfile_dir/dks_const_var.sh rmq_data_path ${rmq_port})
rmq_log_path=$($dks_bashfile_dir/dks_const_var.sh  rmq_log_path  ${rmq_port})
rmq_util_path=$($dks_bashfile_dir/dks_const_var.sh rmq_util_path ${rmq_port})

# Файл обмена относительно хоста и контейнера
host_stdout=$($dks_bashfile_dir/dks_const_var.sh     host_stdout     ${rmq_port})
cont_stdout=$($dks_bashfile_dir/dks_const_var.sh     cont_stdout     ${rmq_port})
dks_host_stdout=$($dks_bashfile_dir/dks_const_var.sh dks_host_stdout ${rmq_port})

# Цвета
sOK=$(echo $($dks_bashfile_dir/dks_const_var.sh sOK) | tr '#' ' ')
wOK=$(echo $($dks_bashfile_dir/dks_const_var.sh wOK) | tr '#' ' ')
eRR=$(echo $($dks_bashfile_dir/dks_const_var.sh eRR) | tr '#' ' ')
emptE=$(echo $($dks_bashfile_dir/dks_const_var.sh emptE) | tr '#' ' ')
emptEsh=$($dks_bashfile_dir/dks_const_var.sh emptE)

# sudo
is_root=$($dks_bashfile_dir/dks_const_var.sh is_root)

function fn_file_clr(){
cat > $1 << EOF
EOF
}

function fn_file_echo() {
local LeftSpace=$2
LeftSpace=$(echo ${LeftSpace} | tr '#' ' ')
cat $1 | while read line
do
 echo -e "${LeftSpace}$line"
 done
}

# =========== Проверка параметров ===================================

echo ""

# Проверка прав суперпользователя
bash ${dks_bashfile_dir}/sys/sys_is_root.sh "install"
if [ $? = "1" ]; then exit 1; fi;

# Проверка корректности значений порта
bash ${dks_bashfile_dir}/sys/sys_checkport.sh "interval" "${rmq_port}" "${rmq_msg_title}" "5672" "5682"
if [ $? = "1" ]; then exit 1; fi;

# Проверка "свободности" порта брокера на хосте
bash ${dks_bashfile_dir}/sys/sys_checkport.sh "free" "${rmq_port}" "${rmq_msg_title}"
if [ $? = "1" ]; then exit 1; fi;

# Проверка "свободности" порта epmd на хосте
bash ${dks_bashfile_dir}/sys/sys_checkport.sh "free" "${erl_epmd_port}" "${epmd_msg_title}"
if [ $? = "1" ]; then exit 1; fi;


# Проверка сервиса d o c k e r или файла podman на хосте
if [ "${contsoft}" = "docker"  ]; then
  contsoftname="Docker"
  consoftchecktype="service"
else
  contsoftname="Podman"
  consoftchecktype="file"
fi;

bash ${dks_bashfile_dir}/sys/sys_checkservice.sh "${contsoft}" "${contsoftname}" "${consoftchecktype}"
if [ $? = "1" ]; then exit 1; fi;


# Проверка , нет ли контейнера с указанным портом и другим именем
if [ ! -z "$(${contsoft} ps -a | grep ">${db_port}/tcp" | grep -v ${dks_cont_name})" ]; then
  echo -e "${eRR}Проверка доступности порта."
  echo -e "${emptE}Порт \"${db_port}\" используется другим контейнером."
  echo -e "${emptE}Операция установки прервана."
  echo ""
  exit 1;
fi

# Проверка в системе развернутых каталогов
if [ -d ${rmq_inst_name} ]; then
  echo -e "${eRR}Проверка предыдущей установки."
  echo -e "${emptE}Каталог управления \"${rmq_inst_name}\" уже существует."
  echo -e "${emptE}Выполните деинсталляцию предудущей установки или удалите каталог вручную."
  echo -e "${emptE}Операция установки прервана."
  echo ""
  exit 1;
fi;

if [ -d ${rmq_data_path} ]; then
  echo -e "${eRR}Проверка предыдущей установки."
  echo -e "${emptE}Каталог данных \"${rmq_data_path}\" уже существует."
  echo -e "${emptE}Выполните деинсталляцию предудущей установки или удалите каталог вручную."
  echo -e "${emptE}Операция установки прервана."
  echo ""
  exit 1;
fi;


#= Подготовка к развертыванию окружения хоста==============
se_mode="Disabled"
# Проверка Selinux
if [ -f /etc/selinux/config ]; then
  se_mode=$(echo $(getenforce))
  if [ "${se_mode}" = "Enforcing" ]; then
    # переключаем в разрешительный :)
    setenforce Permissive
  fi;
fi;

# Удаление принудительно контейнер+образ #############################
${contsoft} container inspect ${dks_cont_name} >/dev/null 2>&1
if [ $? -eq 0 ]; then
  echo -e "${sOK}Удаление контейнера ${dks_cont_name}."
  ${contsoft} rm -f ${dks_cont_name} >/dev/null
fi;

${contsoft} image inspect ${dks_cont_name} >/dev/null 2>&1
if [ $? -eq 0 ]; then
  echo -e "${sOK}Удаление образа ${dks_cont_name}."
  ${contsoft} rmi -f ${dks_cont_name} >/dev/null
fi;

${contsoft} image inspect ${tag_name} >/dev/null 2>&1
if [ $? -eq 0 ]; then
  echo -e "${sOK}Удаление эталонного локального образа ${tag_name}."
  ${contsoft} rmi -f ${tag_name} >/dev/null
fi;
####################################################################

# Создаем Файл обмена на хосте для установки
fn_file_clr ${dks_host_stdout}
chmod 777 ${dks_host_stdout}

# Создание пользователя ks-rabbitmq
bash ${dks_bashfile_dir}/sys/sys_useradd.sh "ks-rabbitmq"
if [ $? = "1" ]; then exit 1; fi;

# Создание каталогов для монтирования для контейнера-докера ######################
mkdir -p ${rmq_inst_name}

# Создание утилит
mkdir -p ${rmq_util_path}
bash ${dks_bashfile_dir}/dks_make_util.sh "${rmq_port}" "${contsoft}"

#Создание конфига
mkdir -p ${rmq_etc_path}

# Копирование файлов конфигов
cp ${dks_inst_path}/template/rabbitmq-env.conf.t   ${rmq_etc_path}/rabbitmq-env.conf
sed -i 's/@rmq_port@/'${rmq_port}'/g'              ${rmq_etc_path}/rabbitmq-env.conf
sed -i 's/@erl_epmd_port@/'${erl_epmd_port}'/g'    ${rmq_etc_path}/rabbitmq-env.conf


cp ${dks_inst_path}/template/rabbitmq.config.t     ${rmq_etc_path}/rabbitmq.config
sed -i 's/@rmq_port@/'${rmq_port}'/g'              ${rmq_etc_path}/rabbitmq.config


#Создание каталога данных и лога
mkdir -p ${rmq_data_path}
mkdir -p ${rmq_data_path}/mnesia
mkdir -p ${rmq_log_path}

####################################################################################


# Владельцем делаем rabbitmq
chown ks-rabbitmq:ks-rabbitmq -R ${rmq_data_path}


# Создаем Файл обмена на хосте для установки
fn_file_clr ${host_stdout}
chmod 777 ${host_stdout}


# Загружаем образ из архива
if [ ! -f "${dks_inst_path}/container_image/${dks_image_tar_file}" ]; then
  echo -e "${eRR}Загрузка эталонного локального образа ${tag_name} из архива ${dks_image_tar_file}"
  echo -e "${emptE}Отсутствует файл архива с образом ${dks_inst_path}/container_image/${dks_image_tar_file}"
  echo -e "${emptE}Операция создания контейнера ${dks_cont_name} невозможна."
  exit 1;
else
  ${contsoft} load -q -i "${dks_inst_path}/container_image/${dks_image_tar_file}" >/dev/null
  echo -e "${sOK}Загрузка эталонного локального образа ${tag_name} из архива ${dks_image_tar_file}."
fi

# Создаем на базе загруженного образа
# копирование Dockerfile
cp ${dks_inst_path}/template/Dockerfile.t      ${dks_inst_path}/container_image/Dockerfile
sed -i 's/@tag_ver@/'${tag_ver}'/g'            ${dks_inst_path}/container_image/Dockerfile

${contsoft} build -q -t ${dks_cont_name} ${dks_inst_path}/container_image >/dev/null
echo -e "${sOK}Построение конечного образа ${dks_cont_name} на базе эталонного."


# Создаем контейнер из образа и запускаем в фоновом режиме
${contsoft} run -d \
           --privileged --device=/dev/mem  \
           --network host \
           -v ${rmq_etc_path}:/etc/rabbitmq:rw,z \
           -v ${rmq_data_path}:/var/lib/rabbitmq:rw,z \
           -v ${rmq_log_path}:/var/log/rabbitmq:rw,z \
           -i \
           --name ${dks_cont_name} ${dks_cont_name} /bin/bash >/dev/null

echo -e "${sOK}Создание контейнера ${dks_cont_name} и запуск."

# Владельцем делаем rabbitmq
chown ks-rabbitmq:ks-rabbitmq -R ${rmq_data_path}

## -- инфа о запуске контейнера
# Определяем запущен ли контейнера
dks_status=$(${contsoft} inspect -f '{{.State.Running}}' ${dks_cont_name})

if [ "$dks_status" = "true" ]; then
  echo -e "${sOK}Запуск контейнера ${dks_cont_name}."
fi

if [ ! -z "$(${contsoft} images | grep ${tag_name})" ]; then
  echo -e "${sOK}Удаление эталонного локального образа ${tag_name}."
  ${contsoft} rmi -f ${tag_name} >/dev/null
fi


# Замена ID пользователя rabbitmq на хостовый ID (считываем в переменные)
# Пользователи с равными ID будут наследовать и права доступа
# Поэтому выравниваем id для пользователя rabbitmq
# символ "/" экранируем в hex-16 -> \x2F

uid_whost=$(id -u ks-rabbitmq)
gid_whost=$(id -g ks-rabbitmq)

run_cmd="groupmod -g ${gid_whost} rabbitmq && usermod -u ${uid_whost} -g ${gid_whost} rabbitmq"
bash ${dks_bashfile_dir}/sys/sys_exec_cont_ex.sh -cs "${contsoft}"      \
                                                 -cn "${dks_cont_name}" \
                                                 -c  "${run_cmd}"       \
                                                 -noout
if [ $? = "1" ]; then exit 1; fi;

echo -e "${sOK}Коррекция пользователя rabbitmq в контейнере ${dks_cont_name}."




# Заново устанавливаем владельца домашней папки и папки с данными
run_cmd="mkdir -p /home/rabbitmq && chown rabbitmq:rabbitmq -R /home/rabbitmq && chown rabbitmq:rabbitmq -R /var/lib/rabbitmq"
bash ${dks_bashfile_dir}/sys/sys_exec_cont_ex.sh -cs "${contsoft}"      \
                                                 -cn "${dks_cont_name}" \
                                                 -c  "${run_cmd}"       \
                                                 -noout
if [ $? = "1" ]; then exit 1; fi;

# Анализируем наличие FireWall и пытаемся добавить правило для открытия порта
bash ${dks_bashfile_dir}/sys/sys_firewall.sh "${rmq_port} ${http_rmq_port}" "tcp"

# помещаем файл информатор, если по контейнеризации podman
rm -f ${rmq_inst_name}/podman
if [ "${contsoft}" = "podman" ]; then
  echo "podman" > ${rmq_inst_name}/podman
fi;


# Создание автозапуска при перезагрузке хоста
if [ -f "/lib/systemd/system/${dks_serv_name}" ]; then
  fn_file_clr /lib/systemd/system/${dks_serv_name}
fi

# Формирование содержимого файла */service
if [ "${contsoft}" = "docker"  ]; then
  requires_service="Requires=docker.service"
  after_service="After=docker.service"
else
  requires_service=""
  after_service=""
fi;


cat > /lib/systemd/system/${dks_serv_name} << EOF
[Unit]
Description=RMQ-КС ${tag_ver}:${rmq_port}
# Запускать после старта сервисов и служб
${requires_service}
After=syslog.target
After=network.target
${after_service}

[Service]
Type=forking
ExecStart=${dks_bashfile_dir}/dks_service.sh start ${rmq_port}
ExecStop=${dks_bashfile_dir}/dks_service.sh stop ${rmq_port}
RemainAfterExit=yes

# Запрет на убийство сервиса вследствие нехватки памяти и срабатывания механизма OOM:
#-1000 полный запрет (такой у sshd стоит), -100 понизим вероятность.
OOMScoreAdjust=-1000

# Таймаут в секундах, сколько ждать system отработки старт/стоп команд.
TimeoutSec=300

[Install]
#Уровень запуска - Многопользовательский режим без графики
WantedBy=multi-user.target
EOF

systemctl daemon-reload

fn_file_echo ${dks_host_stdout} ${emptEsh}
systemctl enable ${dks_serv_name} >/dev/null 2>${dks_host_stdout}
#показываем
fn_file_echo ${dks_host_stdout} ${emptEsh}
fn_file_clr ${dks_host_stdout}


# Запуск напрямую, с предварительной установки поддержки плагина управления
run_cmd="rabbitmq-plugins enable rabbitmq_management"
bash ${dks_bashfile_dir}/sys/sys_exec_cont_ex.sh -cs "${contsoft}"      \
                                                 -cn "${dks_cont_name}" \
                                                 -c  "${run_cmd}"       \
                                                 -noout
if [ $? = "1" ]; then exit 1; fi;

# Останавливаем контейнер
${contsoft} stop -t 1 ${dks_cont_name} >/dev/null
echo -e "${sOK}Остановка контейнера ${dks_cont_name}."


# Активируем сервис
systemctl start ${dks_serv_name}

# Проверяем что служба запустилась
if systemctl -q is-active ${dks_serv_name}; then
  # принудительная задержка, чтобы старт успел пройти в контейнере
  sleep 10
  echo -e "${sOK}Запуск сервиса ${dks_serv_name}."

  bash ${dks_bashfile_dir}/sys/sys_checkproc.sh -cs "${contsoft}"               \
                                                -cn "${dks_cont_name}"          \
                                                -c  "/usr/sbin/rabbitmq-server" \
                                                -sn "rmq_msg_title"


  # Создаем пользователя-администратора
  bash ${dks_bashfile_dir}/dks_nastr_rmq.sh "${rmq_port}" \
                                            "users"       \
                                            "${user}"     \
                                            "${pwd}"      \
                                            "${contsoft}"



else
  echo -e "${eRR}Запуск сервиса ${dks_serv_name}."
  echo -e "${emptE}Была предпринята неудачная попытка запуска сервиса ${dks_serv_name}."
  echo -e "${emptE}Если сервис не будет запущен, то контейнер ${dks_cont_name} не запустится после перезагрузки хоста."
  echo -e "${emptE}Обязательно свяжитесь со свои системным администратором."
fi;


# Удаление ненужных файлов
rm -f ${dks_host_stdout}
rm -f ${host_stdout}
rm -f ${cont_stdout}


# настройка ротации логов
bash ${dks_bashfile_dir}/sys/sys_logrotate.sh "${rmq_log_path}"         \
                                              "${tag_name}_${rmq_port}" \
                                              "${rmq_msg_title}"


# восстанавливаем значение для selinux
if [ "${se_mode}" = "Enforcing" ]; then
  # переключаем обратно
  setenforce Enforcing
fi;


echo ""
exit 0;

