#!/bin/bash

### RMQ-КС
###
### Copyright (c) 2023, ООО Кейсистемс
###
### Версия 3.12.4

# Определяем каталог выполнения текущего скрипта
dks_bashfile_dir="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"

rmq_port=$1

#============== Основные переменные =====================

# Цвета
ErrColor=$($dks_bashfile_dir/dks_const_var.sh     ErrColor)
SuccColor=$($dks_bashfile_dir/dks_const_var.sh    SuccColor)
WarnColor=$($dks_bashfile_dir/dks_const_var.sh    WarnColor)
NoColor=$($dks_bashfile_dir/dks_const_var.sh      NoColor)
eRR=$(echo $($dks_bashfile_dir/dks_const_var.sh   eRR)   | tr '#' ' ')
emptE=$(echo $($dks_bashfile_dir/dks_const_var.sh emptE) | tr '#' ' ')

# Проверка прав суперпользователя
bash ${dks_bashfile_dir}/sys/sys_is_root.sh "run"
if [ $? = "1" ]; then exit 1; fi;

function fn_file_clr(){
cat > $1 << EOF
EOF
}
#==========================================================

# если параметр не передан, то показываем обобщенную инфомацию
if [ -z "${rmq_port}" ]; then

  echo ""
  echo -e "${WarnColor}Существующие контейнеры${NoColor}"
  echo "~~~~~~~~~~~~~~~~~~~~~~~~"
  docker_exists=$(which docker 2>/dev/null)
  if [ ! -z ${docker_exists} ]; then
    echo -e "${WarnColor}Docker:${NoColor}"
    docker ps -a | grep "rmqks\|CONTAINER ID"
  fi;
  podman_exists=$(which podman 2>/dev/null)
  if [ ! -z ${podman_exists} ]; then
    echo -e "${WarnColor}Podman:${NoColor}"
    podman ps -a | grep "rmqks\|CONTAINER ID"
  fi;


  echo ""
  echo -e "${WarnColor}Существующие образы контейнеров${NoColor}"
  echo "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
  docker_exists=$(which docker 2>/dev/null)
  if [ ! -z ${docker_exists} ]; then
    echo -e "${WarnColor}Docker:${NoColor}"
    docker images | grep "rmqks\|IMAGE ID"
  fi;
  podman_exists=$(which podman 2>/dev/null)
  if [ ! -z ${podman_exists} ]; then
    echo -e "${WarnColor}Podman:${NoColor}"
    podman ps -a | grep "rmqks\|CONTAINER ID"
  fi;

  echo ""
  echo -e "${WarnColor}Процессы контейнеров, транслируемые на хост:${NoColor}"
  echo "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
  ps -ef | grep "rabbitmq-server" | grep -v "grep rabbitmq-server" | grep -v "root"

  echo ""
  echo -e "${WarnColor}Сервисы systemd:${NoColor}"
  echo -e "~~~~~~~~~~~~~~~~"
  systemctl list-units rmqks* | grep "UNIT\|rmqks"

  echo ""
  exit 0;
fi;


# Контейнер (считываем наименование контейнера и сервиса)
dks_cont_name=$($dks_bashfile_dir/dks_const_var.sh dks_cont_name ${rmq_port})
dks_serv_name=$($dks_bashfile_dir/dks_const_var.sh dks_serv_name ${rmq_port})
rmq_inst_name=$($dks_bashfile_dir/dks_const_var.sh rmq_inst_name ${rmq_port})
contsoft=$(${rmq_inst_name}/utility/const_var.sh contsoft)


# Файл обмена
host_stdout=$($dks_bashfile_dir/dks_const_var.sh host_stdout ${rmq_port})
cont_stdout=$($dks_bashfile_dir/dks_const_var.sh cont_stdout ${rmq_port})

fn_file_clr ${host_stdout}
chmod 777 ${host_stdout}

echo ""

if [ ! -f "/lib/systemd/system/${dks_serv_name}" ]; then
  echo -e "${ErrColor}Сервис ${dks_serv_name} отсутствует в системе.${NoColor}"
else
  echo -e "${WarnColor}Сервис ${dks_serv_name}:${NoColor}"
  echo -e "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
  systemctl status ${dks_serv_name} --no-pager
fi


echo ""

# Проверяем существование контейнера
dks_exists=$(${contsoft} container ls -a | grep ${dks_cont_name})
if [ -z "${dks_exists}" ]; then
  echo -e "${ErrColor}Контейнера ${dks_cont_name} не существует.${NoColor}"
  echo ""
  exit;
fi

# Определяем запущен ли контейнера
dks_status=$(${contsoft} inspect -f '{{.State.Running}}' ${dks_cont_name})

if [ "${dks_status}" = "false" ]; then
  echo -e "${ErrColor}Контейнер ${dks_cont_name} не запущен.${NoColor}"
  echo ""
  exit;
fi


echo ""
echo -e "${WarnColor}Свойства контейнера ${dks_cont_name}:${NoColor}"
echo -e "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
bash ${dks_bashfile_dir}/sys/sys_exec_cont_ex.sh -cs "${contsoft}" -cn "${dks_cont_name}" -c "echo 'Дата : $(date)'"
bash ${dks_bashfile_dir}/sys/sys_exec_cont_ex.sh -cs "${contsoft}" -cn "${dks_cont_name}" -c "echo 'Часовой пояс : $(date +%Z%:::z)'"

echo ""
echo -e "${WarnColor}Процессы контейнера ${dks_cont_name} (за исключением запущенных под root):${NoColor}"
echo -e "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
bash ${dks_bashfile_dir}/sys/sys_exec_cont_ex.sh -cs "${contsoft}" -cn "${dks_cont_name}" -c "ps -efl | grep -v root"

rm -f ${host_stdout}

echo ""

exit;

