#!/bin/bash

### RMQ-КС
###
### Copyright (c) 2023, ООО Кейсистемс
###
### Версия 3.12.4

if [ -z "$1" ]; then
  rmq_port="5672"
else
  rmq_port=$1
fi

all=$2

# Определяем каталог выполнения текущего скрипта
dks_bashfile_dir="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"


#============== Основные переменные константы =====================
tag_ver=$($dks_bashfile_dir/dks_const_var.sh tag_ver)
tag_name=$($dks_bashfile_dir/dks_const_var.sh tag_name)


# Контейнер
dks_inst_name=$($dks_bashfile_dir/dks_const_var.sh dks_inst_name)
dks_inst_path=$($dks_bashfile_dir/dks_const_var.sh dks_inst_path)

dks_cont_name=$($dks_bashfile_dir/dks_const_var.sh      dks_cont_name      ${rmq_port})
dks_serv_name=$($dks_bashfile_dir/dks_const_var.sh      dks_serv_name      ${rmq_port})
dks_image_tar_file=$($dks_bashfile_dir/dks_const_var.sh dks_image_tar_file ${rmq_port})

# RMQ
rmq_inst_name=$($dks_bashfile_dir/dks_const_var.sh rmq_inst_name ${rmq_port})
rmq_etc_path=$($dks_bashfile_dir/dks_const_var.sh  rmq_etc_path  ${rmq_port})
rmq_data_path=$($dks_bashfile_dir/dks_const_var.sh rmq_data_path ${rmq_port})
rmq_log_path=$($dks_bashfile_dir/dks_const_var.sh  rmq_log_path  ${rmq_port})
rmq_util_path=$($dks_bashfile_dir/dks_const_var.sh rmq_util_path ${rmq_port})


if [ -f "${rmq_util_path}/const_var.sh" ]; then
  contsoft=$(${rmq_util_path}/const_var.sh contsoft)
fi;

# Файл обмена относительно хоста и контейнера
host_stdout=$($dks_bashfile_dir/dks_const_var.sh     host_stdout     ${rmq_port})
cont_stdout=$($dks_bashfile_dir/dks_const_var.sh     cont_stdout     ${rmq_port})
dks_host_stdout=$($dks_bashfile_dir/dks_const_var.sh dks_host_stdout ${rmq_port})

# Цвета
sOK=$(echo $($dks_bashfile_dir/dks_const_var.sh sOK) | tr '#' ' ')
wOK=$(echo $($dks_bashfile_dir/dks_const_var.sh wOK) | tr '#' ' ')
eRR=$(echo $($dks_bashfile_dir/dks_const_var.sh eRR) | tr '#' ' ')
emptE=$(echo $($dks_bashfile_dir/dks_const_var.sh emptE) | tr '#' ' ')
emptEsh=$($dks_bashfile_dir/dks_const_var.sh emptE)

# Проверка прав суперпользователя
bash ${dks_bashfile_dir}/sys/sys_is_root.sh "uninstall"
if [ $? = "1" ]; then exit 1; fi;

function fn_file_clr(){
cat > $1 << EOF
EOF
}

function fn_file_echo() {
local LeftSpace=$2
LeftSpace=$(echo ${LeftSpace} | tr '#' ' ')
cat $1 | while read line
do
 echo -e "${LeftSpace}$line"
 done
}

#==========================================================

echo ""
stop_from_service="no"
no_data="yes"

fn_file_clr ${dks_host_stdout}
chmod 777 ${dks_host_stdout}


# Если есть сервис останавливаем через него, иначе через скрипт
if [ -f "/lib/systemd/system/${dks_serv_name}" ]; then
  if [ "$(systemctl is-active ${dks_serv_name})" = "active" ]; then
    if ! [ -z "${contsoft}" ]; then
      echo -e "${sOK}Остановка контейнера через сервис ${dks_serv_name}."
      systemctl stop ${dks_serv_name}
      fn_file_echo ${dks_host_stdout} ${emptEsh}
    fi;
    systemctl disable ${dks_serv_name} >/dev/null 2>${dks_host_stdout}
    #показываем 
    fn_file_echo ${dks_host_stdout} ${emptEsh}
    fn_file_clr ${dks_host_stdout}

    stop_from_service="yes"
    no_data="no"
  fi;
fi;

# Если через сервис не остановили, то останавливаем через скрипт
if [ "${stop_from_service}" = "no" ]; then
  if ! [ -z "${contsoft}" ]; then 
    bash ${dks_bashfile_dir}/dks_stop.sh ${rmq_port}
  fi;
fi;

# Удаление принудительно контейнер+образ
if ! [ -z "${contsoft}" ]; then
  ${contsoft} container inspect ${dks_cont_name} >/dev/null 2>&1
  if [ $? -eq 0 ]; then
    echo -e "${sOK}Удаление контейнера ${dks_cont_name}."
    ${contsoft} rm -f ${dks_cont_name} >/dev/null
    no_data="no"
  fi;

  ${contsoft} image inspect ${dks_cont_name} >/dev/null 2>&1
  if [ $? -eq 0 ]; then
    echo -e "${sOK}Удаление образа ${dks_cont_name}."
    ${contsoft} rmi -f ${dks_cont_name} >/dev/null
    no_data="no"
  fi;
fi;

# Если есть сервис, то удаляем его
if [ -f "/lib/systemd/system/${dks_serv_name}" ]; then
  rm -f /lib/systemd/system/${dks_serv_name}
fi;

# Передан ключ удаления каталогов
if ! [ -z "${all}" ]; then
  if [ -d ${rmq_inst_name} ]; then
    echo -e "${sOK}Удаление каталога управления ${rmq_inst_name}."
    rm -Rf ${rmq_inst_name}
    no_data="no"
  fi;

  if [ -d ${rmq_data_path} ]; then
    echo -e "${sOK}Удаление каталога данных ${rmq_data_path}."
    rm -Rf ${rmq_data_path}
    no_data="no"
  fi;
fi;

# файл обмена
rm -f  ${dks_host_stdout}

if [ ${no_data} = "yes" ]; then
  echo -e "${wOK}Нет данных для удаления."
fi;

echo ""
exit;


